EXPORTS
	??0CCFChannelPairRawBase@CommsFW@@QAE@HPAVRMsgQueueBase@@AAVRCFChannelRawBase@1@01HH@Z @ 1 NONAME ; public: __thiscall CommsFW::CCFChannelPairRawBase::CCFChannelPairRawBase(int,class RMsgQueueBase *,class CCFChannelPairRawBase::RCFChannelRawBase &,class RMsgQueueBase *,class CCFChannelPairRawBase::RCFChannelRawBase &,int,int)
	??0CCFModuleChannelHandler@CommsFW@@IAE@H@Z @ 2 NONAME ; protected: __thiscall CommsFW::CCFModuleChannelHandler::CCFModuleChannelHandler(int)
	??0RCFChannelRawBase@CommsFW@@QAE@XZ @ 3 NONAME ; public: __thiscall CommsFW::RCFChannelRawBase::RCFChannelRawBase(void)
	??0TCFSubModuleAddress@CommsFW@@QAE@ABV01@@Z @ 4 NONAME ; public: __thiscall CommsFW::TCFSubModuleAddress::TCFSubModuleAddress(class TCFSubModuleAddress::TCFSubModuleAddress const &)
	??0TCFSubModuleAddress@CommsFW@@QAE@ABV?$TBuf8@$0CA@@@0@Z @ 5 NONAME ; public: __thiscall CommsFW::TCFSubModuleAddress::TCFSubModuleAddress(class TBuf8<32> const &,class TBuf8<32> const &)
	??0TCFSubModuleAddress@CommsFW@@QAE@XZ @ 6 NONAME ; public: __thiscall CommsFW::TCFSubModuleAddress::TCFSubModuleAddress(void)
	??1CCFChannelPairRawBase@CommsFW@@UAE@XZ @ 7 NONAME ; public: virtual __thiscall CommsFW::CCFChannelPairRawBase::~CCFChannelPairRawBase(void)
	??1CCFModuleChannelHandler@CommsFW@@MAE@XZ @ 8 NONAME ; protected: virtual __thiscall CommsFW::CCFModuleChannelHandler::~CCFModuleChannelHandler(void)
	??1RCFChannelRawBase@CommsFW@@QAE@XZ @ 9 NONAME ; public: __thiscall CommsFW::RCFChannelRawBase::~RCFChannelRawBase(void)
	??4TCFSubModuleAddress@CommsFW@@QAEAAV01@ABV01@@Z @ 10 NONAME ; public: class CommsFW::TCFSubModuleAddress & __thiscall CommsFW::TCFSubModuleAddress::operator=(class CommsFW::TCFSubModuleAddress const &)
	??8TCFSubModuleAddress@CommsFW@@QBEHABV01@@Z @ 11 NONAME ; public: int __thiscall CommsFW::TCFSubModuleAddress::operator==(class CommsFW::TCFSubModuleAddress const &)const 
	??9TCFSubModuleAddress@CommsFW@@QBEHABV01@@Z @ 12 NONAME ; public: int __thiscall CommsFW::TCFSubModuleAddress::operator!=(class CommsFW::TCFSubModuleAddress const &)const 
	?CFChannelError@CCFModuleChannelHandler@CommsFW@@MAEXH@Z @ 13 NONAME ; protected: virtual void __thiscall CommsFW::CCFModuleChannelHandler::CFChannelError(int)
	?CFMessageBind@CCFModuleChannelHandler@CommsFW@@MAEXABVTCFBindMsg@2@@Z @ 14 NONAME ; protected: virtual void __thiscall CommsFW::CCFModuleChannelHandler::CFMessageBind(class CommsFW::TCFBindMsg const &)
	?CFMessageDiscover@CCFModuleChannelHandler@CommsFW@@MAEXABVTCFDiscoverMsg@2@@Z @ 15 NONAME ; protected: virtual void __thiscall CommsFW::CCFModuleChannelHandler::CFMessageDiscover(class CommsFW::TCFDiscoverMsg const &)
	?CFMessageShutdown@CCFModuleChannelHandler@CommsFW@@MAEXABVTCFShutdownMsg@2@@Z @ 16 NONAME ; protected: virtual void __thiscall CommsFW::CCFModuleChannelHandler::CFMessageShutdown(class CommsFW::TCFShutdownMsg const &)
	?CFMessageUnbind@CCFModuleChannelHandler@CommsFW@@MAEXABVTCFUnbindMsg@2@@Z @ 17 NONAME ; protected: virtual void __thiscall CommsFW::CCFModuleChannelHandler::CFMessageUnbind(class CommsFW::TCFUnbindMsg const &)
	?CFMessageUnknown@CCFModuleChannelHandler@CommsFW@@MAEXABVTCFMessage@2@@Z @ 18 NONAME ; protected: virtual void __thiscall CommsFW::CCFModuleChannelHandler::CFMessageUnknown(class CommsFW::TCFMessage const &)
	?CancelDataAvailable@CCFChannelPairRawBase@CommsFW@@QAEXXZ @ 19 NONAME ; public: void __thiscall CommsFW::CCFChannelPairRawBase::CancelDataAvailable(void)
	?CancelDataAvailable@RCFChannelRawBase@CommsFW@@QAEXPAVRMsgQueueBase@@@Z @ 20 NONAME ; public: void __thiscall CommsFW::RCFChannelRawBase::CancelDataAvailable(class RMsgQueueBase *)
	?CancelSpaceAvailable@CCFChannelPairRawBase@CommsFW@@QAEXH@Z @ 21 NONAME ; public: void __thiscall CommsFW::CCFChannelPairRawBase::CancelSpaceAvailable(int)
	?CancelSpaceAvailable@RCFChannelRawBase@CommsFW@@QAEXHPAVRMsgQueueBase@@@Z @ 22 NONAME ; public: void __thiscall CommsFW::RCFChannelRawBase::CancelSpaceAvailable(int,class RMsgQueueBase *)
	?Close@RCFChannelRawBase@CommsFW@@QAEXPAVRMsgQueueBase@@H@Z @ 23 NONAME ; public: void __thiscall CommsFW::RCFChannelRawBase::Close(class RMsgQueueBase *,int)
	?CloseGracefully@CCFChannelPairRawBase@CommsFW@@QAEHH@Z @ 24 NONAME ; public: int __thiscall CommsFW::CCFChannelPairRawBase::CloseGracefully(int)
	?CloseNonGracefully@CCFChannelPairRawBase@CommsFW@@QAEXXZ @ 25 NONAME ; public: void __thiscall CommsFW::CCFChannelPairRawBase::CloseNonGracefully(void)
	?ConstructL@CCFModuleChannelHandler@CommsFW@@IAEXAAUTMsgQueuesTAG@?$RCFChannelBase@VTCFMessage@CommsFW@@$00@2@0@Z @ 26 NONAME ; protected: void __thiscall CommsFW::CCFModuleChannelHandler::ConstructL(struct CommsFW::RCFChannelBase<class CommsFW::TCFMessage,1>::TMsgQueuesTAG &,struct CommsFW::RCFChannelBase<class CommsFW::TCFMessage,1>::TMsgQueuesTAG &)
	?Create@RCFChannelRawBase@CommsFW@@QAEHHHPAVRMsgQueueBase@@H@Z @ 27 NONAME ; public: int __thiscall CommsFW::RCFChannelRawBase::Create(int,int,class RMsgQueueBase *,int)
	?Create@RCFChannelRawBase@CommsFW@@QAEHPBVRMsgQueueBase@@W4TOwnerType@@PAV3@H@Z @ 28 NONAME ; public: int __thiscall CommsFW::RCFChannelRawBase::Create(class RMsgQueueBase const *,enum TOwnerType,class RMsgQueueBase *,int)
	?Create@RCFThread@CommsFW@@QAEHABVTDesC16@@P6AHPAX@ZHHH1@Z @ 29 NONAME ABSENT ; public: int __thiscall CommsFW::RCFThread::Create(class TDesC16 const &,int (__cdecl*)(void *),int,int,int,void *)
	?Create@RCFThread@CommsFW@@QAEHABVTDesC16@@P6AHPAX@ZHPAVRHeap@@1@Z @ 30 NONAME ABSENT ; public: int __thiscall CommsFW::RCFThread::Create(class TDesC16 const &,int (__cdecl*)(void *),int,class RHeap *,void *)
	?CreateRecv@CCFChannelPairRawBase@CommsFW@@QAEHH@Z @ 31 NONAME ; public: int __thiscall CommsFW::CCFChannelPairRawBase::CreateRecv(int)
	?CreateRecv@CCFChannelPairRawBase@CommsFW@@QAEHPBVRMsgQueueBase@@W4TOwnerType@@@Z @ 32 NONAME ; public: int __thiscall CommsFW::CCFChannelPairRawBase::CreateRecv(class RMsgQueueBase const *,enum TOwnerType)
	?CreateSend@CCFChannelPairRawBase@CommsFW@@QAEHH@Z @ 33 NONAME ; public: int __thiscall CommsFW::CCFChannelPairRawBase::CreateSend(int)
	?CreateSend@CCFChannelPairRawBase@CommsFW@@QAEHPBVRMsgQueueBase@@W4TOwnerType@@@Z @ 34 NONAME ; public: int __thiscall CommsFW::CCFChannelPairRawBase::CreateSend(class RMsgQueueBase const *,enum TOwnerType)
	?DoCancel@CCFChannelPairRawBase@CommsFW@@MAEXXZ @ 35 NONAME ; protected: virtual void __thiscall CommsFW::CCFChannelPairRawBase::DoCancel(void)
	?DoCancel@CCFModuleChannelHandler@CommsFW@@EAEXXZ @ 36 NONAME ; private: virtual void __thiscall CommsFW::CCFModuleChannelHandler::DoCancel(void)
	?DoSendPIG@CCFChannelPairRawBase@CommsFW@@IAEHPBX@Z @ 37 NONAME ; protected: int __thiscall CommsFW::CCFChannelPairRawBase::DoSendPIG(void const *)
	?GetMsgQueues@RCFChannelRawBase@CommsFW@@QBEXPAVRMsgQueueBase@@PBV3@H@Z @ 38 NONAME ; public: void __thiscall CommsFW::RCFChannelRawBase::GetMsgQueues(class RMsgQueueBase *,class RMsgQueueBase const *,int)const 
	?GetRecvMsgQueues@CCFChannelPairRawBase@CommsFW@@QBEXPAVRMsgQueueBase@@@Z @ 39 NONAME ; public: void __thiscall CommsFW::CCFChannelPairRawBase::GetRecvMsgQueues(class RMsgQueueBase *)const 
	?GetSendMsgQueues@CCFChannelPairRawBase@CommsFW@@QBEXPAVRMsgQueueBase@@@Z @ 40 NONAME ; public: void __thiscall CommsFW::CCFChannelPairRawBase::GetSendMsgQueues(class RMsgQueueBase *)const 
	?IsMsgPIG@CCFChannelPairRawBase@CommsFW@@MAEHPBX@Z @ 41 NONAME ; protected: virtual int __thiscall CommsFW::CCFChannelPairRawBase::IsMsgPIG(void const *)
	?IsOpen@RCFChannelRawBase@CommsFW@@QBEHPBVRMsgQueueBase@@@Z @ 42 NONAME ; public: int __thiscall CommsFW::RCFChannelRawBase::IsOpen(class RMsgQueueBase const *)const 
	?NotifyDataAvailable@CCFChannelPairRawBase@CommsFW@@QAEXAAVTRequestStatus@@@Z @ 43 NONAME ; public: void __thiscall CommsFW::CCFChannelPairRawBase::NotifyDataAvailable(class TRequestStatus &)
	?NotifyDataAvailable@RCFChannelRawBase@CommsFW@@QAEXAAVTRequestStatus@@PAVRMsgQueueBase@@@Z @ 44 NONAME ; public: void __thiscall CommsFW::RCFChannelRawBase::NotifyDataAvailable(class TRequestStatus &,class RMsgQueueBase *)
	?NotifySpaceAvailable@CCFChannelPairRawBase@CommsFW@@QAEXAAVTRequestStatus@@H@Z @ 45 NONAME ; public: void __thiscall CommsFW::CCFChannelPairRawBase::NotifySpaceAvailable(class TRequestStatus &,int)
	?NotifySpaceAvailable@RCFChannelRawBase@CommsFW@@QAEXAAVTRequestStatus@@HPAVRMsgQueueBase@@@Z @ 46 NONAME ; public: void __thiscall CommsFW::RCFChannelRawBase::NotifySpaceAvailable(class TRequestStatus &,int,class RMsgQueueBase *)
	?Printable@TCFSubModuleAddress@CommsFW@@QBEAAV?$TBuf8@$0EB@@@AAV3@@Z @ 47 NONAME ; public: class TBuf8<65> & __thiscall CommsFW::TCFSubModuleAddress::Printable(class TBuf8<65> &)const 
	?Receive@CCFChannelPairRawBase@CommsFW@@QAEHPAX@Z @ 48 NONAME ; public: int __thiscall CommsFW::CCFChannelPairRawBase::Receive(void *)
	?Receive@RCFChannelRawBase@CommsFW@@QAEHPAXHPAVRMsgQueueBase@@H@Z @ 49 NONAME ; public: int __thiscall CommsFW::RCFChannelRawBase::Receive(void *,int,class RMsgQueueBase *,int)
	?RunL@CCFChannelPairRawBase@CommsFW@@MAEXXZ @ 50 NONAME ; protected: virtual void __thiscall CommsFW::CCFChannelPairRawBase::RunL(void)
	?RunL@CCFModuleChannelHandler@CommsFW@@EAEXXZ @ 51 NONAME ; private: virtual void __thiscall CommsFW::CCFModuleChannelHandler::RunL(void)
	?Send@CCFChannelPairRawBase@CommsFW@@QAEHPBXH@Z @ 52 NONAME ; public: int __thiscall CommsFW::CCFChannelPairRawBase::Send(void const *,int)
	?Send@CCFModuleChannelHandler@CommsFW@@IAEHABVTCFMessage@2@@Z @ 53 NONAME ; protected: int __thiscall CommsFW::CCFModuleChannelHandler::Send(class CommsFW::TCFMessage const &)
	?Send@RCFChannelRawBase@CommsFW@@QAEHPBXHHPAVRMsgQueueBase@@@Z @ 54 NONAME ; public: int __thiscall CommsFW::RCFChannelRawBase::Send(void const *,int,int,class RMsgQueueBase *)
	?SendPIG@CCFChannelPairRawBase@CommsFW@@MAEHXZ @ 55 NONAME ; protected: virtual int __thiscall CommsFW::CCFChannelPairRawBase::SendPIG(void)
	?SetModule@TCFSubModuleAddress@CommsFW@@QAEXABV?$TBuf8@$0CA@@@@Z @ 56 NONAME ; public: void __thiscall CommsFW::TCFSubModuleAddress::SetModule(class TBuf8<32> const &)
	?SetSubModule@TCFSubModuleAddress@CommsFW@@QAEXABV?$TBuf8@$0CA@@@@Z @ 57 NONAME ; public: void __thiscall CommsFW::TCFSubModuleAddress::SetSubModule(class TBuf8<32> const &)
	?GetVarFromIniData@CommsFW@@YAHABVTDesC8@@00AAVTPtrC8@@@Z @ 58 NONAME ; int CommsFW::GetVarFromIniData(class TDesC8 const &, class TDesC8 const &, class TDesC8 const &, class TPtrC8 &)
	??0TOwnEntry@COwnEntryList@CommsFW@@QAE@ABVTParse@@ABVTEntry@@@Z @ 59 NONAME ; CommsFW::COwnEntryList::TOwnEntry::TOwnEntry(class TParse const &, class TEntry const &)
	??ACOwnEntryList@CommsFW@@QBEABVTOwnEntry@01@H@Z @ 60 NONAME ; class CommsFW::COwnEntryList::TOwnEntry const & CommsFW::COwnEntryList::operator[](int) const
	?AddL@COwnEntryList@CommsFW@@QAEXABV12@@Z @ 61 NONAME ; void CommsFW::COwnEntryList::AddL(class CommsFW::COwnEntryList const &)
	?AddL@COwnEntryList@CommsFW@@QAEXABVTOwnEntry@12@@Z @ 62 NONAME ; void CommsFW::COwnEntryList::AddL(class CommsFW::COwnEntryList::TOwnEntry const &)
	?Count@COwnEntryList@CommsFW@@QBEHXZ @ 63 NONAME ; int CommsFW::COwnEntryList::Count(void) const
	?WildScanAcrossDrivesL@COwnEntryList@CommsFW@@QAEXABVTDesC16@@0@Z @ 64 NONAME ; void CommsFW::COwnEntryList::WildScanAcrossDrivesL(class TDesC16 const &, class TDesC16 const &)
	??0COwnEntryList@CommsFW@@QAE@H@Z @ 65 NONAME ; CommsFW::COwnEntryList::COwnEntryList(int)
	??1COwnEntryList@CommsFW@@UAE@XZ @ 66 NONAME ; CommsFW::COwnEntryList::~COwnEntryList(void)
	?AccessCount@RCFSharedHeap@CommsFW@@QBEHXZ @ 67 NONAME ; int CommsFW::RCFSharedHeap::AccessCount(void) const
	?LogAllocatedCells@RCFSharedHeap@CommsFW@@QAEXABVTDesC8@@0@Z @ 68 NONAME ; void CommsFW::RCFSharedHeap::LogAllocatedCells(class TDesC8 const &, class TDesC8 const &)
	?CFMessageForward@CCFModuleChannelHandler@CommsFW@@MAEXABVTCFForwardMsg@2@@Z @ 69 NONAME ; void CommsFW::CCFModuleChannelHandler::CFMessageForward(class CommsFW::TCFForwardMsg const &)
	?UniqueWildScanAcrossDrivesL@COwnEntryList@CommsFW@@QAEXABVTDesC16@@0@Z @ 70 NONAME ; void CommsFW::COwnEntryList::UniqueWildScanAcrossDrivesL(class TDesC16 const &, class TDesC16 const &)
	??1CCommsTransport@CommsFW@@UAE@XZ @ 71 NONAME ; CommsFW::CCommsTransport::~CCommsTransport(void)
	?AddClient@CPerfMetricStore@CommsFW@@SAXPAXP6AH0AAVTDes8@@PAVTDes8Overflow@@@Z@Z @ 72 NONAME ; void CommsFW::CPerfMetricStore::AddClient(void *, int (*)(void *, class TDes8 &, class TDes8Overflow *))
	?Clear@TWorkerThreadDataBase@CommsFW@@QAEXXZ @ 73 NONAME ; void CommsFW::TWorkerThreadDataBase::Clear(void)
	?ConvertVal@CommsFW@@YAHABVTDesC8@@AAG@Z @ 74 NONAME ; int CommsFW::ConvertVal(class TDesC8 const &, unsigned short &)
	?ConvertVal@CommsFW@@YAHABVTDesC8@@AAK@Z @ 75 NONAME ; int CommsFW::ConvertVal(class TDesC8 const &, unsigned long &)
	?DeregisterAddress@CCommsTransport@CommsFW@@QAEXAAVTRuntimeCtxId@Messages@@@Z @ 76 NONAME ; void CommsFW::CCommsTransport::DeregisterAddress(class Messages::TRuntimeCtxId &)
	?Destroy@CPerfMetricStore@CommsFW@@SAXXZ @ 77 NONAME ; void CommsFW::CPerfMetricStore::Destroy(void)
	?DropTransportToPeer@CCommsTransport@CommsFW@@QAEHG@Z @ 78 NONAME ; int CommsFW::CCommsTransport::DropTransportToPeer(unsigned short)
	?EstablishTransportToPeer@CCommsTransport@CommsFW@@QAEHGABVRCFChannelMsgQueues@2@0@Z @ 79 NONAME ; int CommsFW::CCommsTransport::EstablishTransportToPeer(unsigned short, class CommsFW::RCFChannelMsgQueues const &, class CommsFW::RCFChannelMsgQueues const &)
	?GetReceiver@CCommsTransport@CommsFW@@QAEAAVMTransportReceiver@Messages@@XZ @ 80 NONAME ; class Messages::MTransportReceiver & CommsFW::CCommsTransport::GetReceiver(void)
	?GetSender@CCommsTransport@CommsFW@@QAEAAVMTransportSender@Messages@@XZ @ 81 NONAME ; class Messages::MTransportSender & CommsFW::CCommsTransport::GetSender(void)
	?Init@TWorkerThreadDataBase@CommsFW@@QAEXGH@Z @ 82 NONAME ; void CommsFW::TWorkerThreadDataBase::Init(unsigned short, int)
	?IsDropTransportPending@CCommsTransport@CommsFW@@QBEHG@Z @ 83 NONAME ; int CommsFW::CCommsTransport::IsDropTransportPending(unsigned short) const
	?LastRequestIdConcerningPeer@CCommsTransport@CommsFW@@QBEHG@Z @ 84 NONAME ; int CommsFW::CCommsTransport::LastRequestIdConcerningPeer(unsigned short) const
	?NewL@CCommsTransport@CommsFW@@SAPAV12@AAVMWorkerThreadRegister@2@PBVCMetaDataVirtualCtorInPlace@Meta@@PAVCCFTransportHooks@2@@Z @ 85 NONAME ; class CommsFW::CCommsTransport * CommsFW::CCommsTransport::NewL(class CommsFW::MWorkerThreadRegister &, class Meta::CMetaDataVirtualCtorInPlace const *, class CommsFW::CCFTransportHooks *)
	?NewL@CPerfMetricStore@CommsFW@@SAPAV12@HVTTimeIntervalMicroSeconds32@@@Z @ 86 NONAME ; class CommsFW::CPerfMetricStore * CommsFW::CPerfMetricStore::NewL(int, class TTimeIntervalMicroSeconds32)
	?Panic@CommsFW@@YAXW4TCFTransportPanics@1@@Z @ 87 NONAME ; void CommsFW::Panic(enum CommsFW::TCFTransportPanics)
	?PeerReachable@CCommsTransport@CommsFW@@QBEHG@Z @ 88 NONAME ; int CommsFW::CCommsTransport::PeerReachable(unsigned short) const
	?PostMessage@CCommsTransport@CommsFW@@AAEXABVTRuntimeCtxId@Messages@@0ABVTDesC8@@@Z @ 89 NONAME ; void CommsFW::CCommsTransport::PostMessage(class Messages::TRuntimeCtxId const &, class Messages::TRuntimeCtxId const &, class TDesC8 const &)
	?PostMessage@CCommsTransport@CommsFW@@QAEXABVTCFMessage@2@@Z @ 90 NONAME ; void CommsFW::CCommsTransport::PostMessage(class CommsFW::TCFMessage const &)
	?RegisterAddress@CCommsTransport@CommsFW@@QAEXAAVTRuntimeCtxId@Messages@@@Z @ 91 NONAME ; void CommsFW::CCommsTransport::RegisterAddress(class Messages::TRuntimeCtxId &)
	?RegisterLegacyInterface@CCommsTransport@CommsFW@@QAEXPAVMLegacyMessageReceiver@2@@Z @ 92 NONAME ; void CommsFW::CCommsTransport::RegisterLegacyInterface(class CommsFW::MLegacyMessageReceiver *)
	?RegisteredCount@CCommsTransport@CommsFW@@QBEHXZ @ 93 NONAME ; int CommsFW::CCommsTransport::RegisteredCount(void) const
	?RemoveClient@CPerfMetricStore@CommsFW@@SAXPAX@Z @ 94 NONAME ; void CommsFW::CPerfMetricStore::RemoveClient(void *)
	?SendMessageSync@CCommsTransport@CommsFW@@AAEXABVTCFMessage@2@@Z @ 95 NONAME ; void CommsFW::CCommsTransport::SendMessageSync(class CommsFW::TCFMessage const &)
	?SetDropTransportPending@CCommsTransport@CommsFW@@QAEXGH@Z @ 96 NONAME ; void CommsFW::CCommsTransport::SetDropTransportPending(unsigned short, int)
	?SetLastRequestIdConcerningPeer@CCommsTransport@CommsFW@@QAEXGH@Z @ 97 NONAME ; void CommsFW::CCommsTransport::SetLastRequestIdConcerningPeer(unsigned short, int)
	?WorkerId@CCommsTransport@CommsFW@@QBEGXZ @ 98 NONAME ; unsigned short CommsFW::CCommsTransport::WorkerId(void) const
	?GetVarFromIniData@CommsFW@@YAHABVTDesC8@@00AAH@Z @ 99 NONAME ; int CommsFW::GetVarFromIniData(class TDesC8 const &, class TDesC8 const &, class TDesC8 const &, int &)


